@@ -37,6 +37,7 @@ class LetsEncryptCertificate(
         name: builtins.str,
         contact_id: typing.Optional[jsii.Number] = None,
         domain_id: typing.Optional[builtins.str] = None,
+        signature_algorithm: typing.Optional[builtins.str] = None,
         timeouts: typing.Optional[typing.Union["LetsEncryptCertificateTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
         connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
@@ -54,6 +55,7 @@ class LetsEncryptCertificate(
         :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/dnsimple/r/lets_encrypt_certificate#name LetsEncryptCertificate#name}.
         :param contact_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/dnsimple/r/lets_encrypt_certificate#contact_id LetsEncryptCertificate#contact_id}.
         :param domain_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/dnsimple/r/lets_encrypt_certificate#domain_id LetsEncryptCertificate#domain_id}.
+        :param signature_algorithm: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/dnsimple/r/lets_encrypt_certificate#signature_algorithm LetsEncryptCertificate#signature_algorithm}.
         :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/dnsimple/r/lets_encrypt_certificate#timeouts LetsEncryptCertificate#timeouts}
         :param connection: 
         :param count: 
@@ -72,6 +74,7 @@ class LetsEncryptCertificate(
             name=name,
             contact_id=contact_id,
             domain_id=domain_id,
+            signature_algorithm=signature_algorithm,
             timeouts=timeouts,
             connection=connection,
             count=count,
@@ -101,6 +104,10 @@ class LetsEncryptCertificate(
     def reset_domain_id(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetDomainId", []))
 
+    @jsii.member(jsii_name="resetSignatureAlgorithm")
+    def reset_signature_algorithm(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetSignatureAlgorithm", []))
+
     @jsii.member(jsii_name="resetTimeouts")
     def reset_timeouts(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetTimeouts", []))
@@ -181,6 +188,11 @@ class LetsEncryptCertificate(
     def name_input(self) -> typing.Optional[builtins.str]:
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))
 
+    @builtins.property
+    @jsii.member(jsii_name="signatureAlgorithmInput")
+    def signature_algorithm_input(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "signatureAlgorithmInput"))
+
     @builtins.property
     @jsii.member(jsii_name="timeoutsInput")
     def timeouts_input(
@@ -239,6 +251,18 @@ class LetsEncryptCertificate(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="signatureAlgorithm")
+    def signature_algorithm(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "signatureAlgorithm"))
+
+    @signature_algorithm.setter
+    def signature_algorithm(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__655ca0045fe932de4e65bdfa00a161f01e317646b4fd62fde46768450f4db5a6)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "signatureAlgorithm", value)
+
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-dnsimple.letsEncryptCertificate.LetsEncryptCertificateConfig",
@@ -255,6 +279,7 @@ class LetsEncryptCertificate(
         "name": "name",
         "contact_id": "contactId",
         "domain_id": "domainId",
+        "signature_algorithm": "signatureAlgorithm",
         "timeouts": "timeouts",
     },
 )
@@ -273,6 +298,7 @@ class LetsEncryptCertificateConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         name: builtins.str,
         contact_id: typing.Optional[jsii.Number] = None,
         domain_id: typing.Optional[builtins.str] = None,
+        signature_algorithm: typing.Optional[builtins.str] = None,
         timeouts: typing.Optional[typing.Union["LetsEncryptCertificateTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
@@ -287,6 +313,7 @@ class LetsEncryptCertificateConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         :param name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/dnsimple/r/lets_encrypt_certificate#name LetsEncryptCertificate#name}.
         :param contact_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/dnsimple/r/lets_encrypt_certificate#contact_id LetsEncryptCertificate#contact_id}.
         :param domain_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/dnsimple/r/lets_encrypt_certificate#domain_id LetsEncryptCertificate#domain_id}.
+        :param signature_algorithm: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/dnsimple/r/lets_encrypt_certificate#signature_algorithm LetsEncryptCertificate#signature_algorithm}.
         :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/dnsimple/r/lets_encrypt_certificate#timeouts LetsEncryptCertificate#timeouts}
         '''
         if isinstance(lifecycle, dict):
@@ -306,6 +333,7 @@ class LetsEncryptCertificateConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument contact_id", value=contact_id, expected_type=type_hints["contact_id"])
             check_type(argname="argument domain_id", value=domain_id, expected_type=type_hints["domain_id"])
+            check_type(argname="argument signature_algorithm", value=signature_algorithm, expected_type=type_hints["signature_algorithm"])
             check_type(argname="argument timeouts", value=timeouts, expected_type=type_hints["timeouts"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
             "auto_renew": auto_renew,
@@ -329,6 +357,8 @@ class LetsEncryptCertificateConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             self._values["contact_id"] = contact_id
         if domain_id is not None:
             self._values["domain_id"] = domain_id
+        if signature_algorithm is not None:
+            self._values["signature_algorithm"] = signature_algorithm
         if timeouts is not None:
             self._values["timeouts"] = timeouts
 
@@ -420,6 +450,12 @@ class LetsEncryptCertificateConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         result = self._values.get("domain_id")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def signature_algorithm(self) -> typing.Optional[builtins.str]:
+        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/dnsimple/r/lets_encrypt_certificate#signature_algorithm LetsEncryptCertificate#signature_algorithm}.'''
+        result = self._values.get("signature_algorithm")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def timeouts(self) -> typing.Optional["LetsEncryptCertificateTimeouts"]:
         '''timeouts block.
@@ -552,6 +588,7 @@ def _typecheckingstub__baf9170565dd5a0e411aa9fc260d074a96b9161acd4607bcb9162bf77
     name: builtins.str,
     contact_id: typing.Optional[jsii.Number] = None,
     domain_id: typing.Optional[builtins.str] = None,
+    signature_algorithm: typing.Optional[builtins.str] = None,
     timeouts: typing.Optional[typing.Union[LetsEncryptCertificateTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
     connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
     count: typing.Optional[jsii.Number] = None,
@@ -588,6 +625,12 @@ def _typecheckingstub__9eabc0e6d5c719ce5d80048a75d4cebd06f55e946841ab50039b3663e
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__655ca0045fe932de4e65bdfa00a161f01e317646b4fd62fde46768450f4db5a6(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__850d843c640aa5551388a4b8af50716ee9c777d9927cb4bc9dda2315153cf876(
     *,
     connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
@@ -601,6 +644,7 @@ def _typecheckingstub__850d843c640aa5551388a4b8af50716ee9c777d9927cb4bc9dda23151
     name: builtins.str,
     contact_id: typing.Optional[jsii.Number] = None,
     domain_id: typing.Optional[builtins.str] = None,
+    signature_algorithm: typing.Optional[builtins.str] = None,
     timeouts: typing.Optional[typing.Union[LetsEncryptCertificateTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
 ) -> None:
     """Type checking stubs"""
